# discord_oauth2

A python library that uses discord's api for easy authentication for your application!

## Installation

Install discord-oauth2 with npm

```bash
  pip3 install discord-oauth2
```

## Documentation

Read the docs [here](https://paulablaza.github.io/discord-oauth2/)

## Contributing

Contributions are always welcome!

If you want to contribute please open an issue first.

## FAQ

- This is my very first python library.
- When you select a function on VSCode, it will show some messages on how you will use it and what are the parameters.

## Author

- [@paulablaza](https://www.github.com/paulablaza)

## License

[MIT](LICENSE)
